@@ -4,23 +4,19 @@ package File::HomeDir::MacOS9;
 # Provided mainly to provide legacy compatibility. May be removed at
 # a later date.
 
-use 5.00503;
+use 5.005;
 use strict;
-use Carp                  ();
-use File::HomeDir::Driver ();
+use Carp ();
 
-use vars qw{$VERSION @ISA};
+# Globals
+use vars qw{$VERSION};
 BEGIN {
-	$VERSION = '0.96_04';
-	@ISA     = 'File::HomeDir::Driver';
+	$VERSION = '0.50';
 }
 
-# Load early if in a forking environment and we have
-# prefork, or at run-time if not.
-SCOPE: {
-	local $@;
-	eval "use prefork 'Mac::Files'";
-}
+# If prefork is available, set Mac::Files
+# to be preloaded if needed.
+eval "use prefork 'Mac::Files'";
 
 
 
@@ -40,13 +36,10 @@ sub my_home {
 	### DESPERATION SETS IN
 
 	# We could use the desktop
-	SCOPE: {
-		local $@;
-		eval {
-			my $home = $class->my_desktop;
-			return $home if $home and -d $home;
-		};
-	}
+	eval {
+		my $home = $class->my_desktop;
+		return $home if $home and -d $home;
+	};
 
 	# Desperation on any platform
 	SCOPE: {
@@ -74,6 +67,14 @@ sub my_desktop {
 	Carp::croak("Could not locate current user's desktop");
 }
 
+sub my_documents {
+	Carp::croak("my_documents is not implemented on Mac OS 9");
+}
+
+sub my_data {
+	Carp::croak("my_data is not implemented on Mac OS 9");
+}
+
 
 
 
@@ -94,57 +95,19 @@ sub users_home {
 	Carp::croak("Failed to find home directory for user '$name'");
 }
 
+sub users_desktop {
+	my ($class, $name) = @_;
+	Carp::croak("users_desktop is not implemented on this platform");
+}
+
+sub users_documents {
+	my ($class, $name) = @_;
+	Carp::croak("users_documents is not implemented on this platform");
+}
+
+sub users_data {
+	my ($class, $name) = @_;
+	Carp::croak("users_data is not implemented on this platform");
+}
+	
 1;
-
-=pod
-
-=head1 NAME
-
-File::HomeDir::MacOS9 - Find your home and other directories on legacy Macs
-
-=head1 SYNOPSIS
-
-  use File::HomeDir;
-  
-  # Find directories for the current user
-  $home    = File::HomeDir->my_home;
-  $desktop = File::HomeDir->my_desktop;
-
-=head1 DESCRIPTION
-
-This module provides implementations for determining common user
-directories on legacy Mac hosts. In normal usage this module will always be
-used via L<File::HomeDir>.
-
-This module is no longer actively maintained, and is included only for
-extreme back-compatibility.
-
-Only the C<my_home> and C<my_desktop> methods are supported.
-
-=head1 SUPPORT
-
-See the support section the main L<File::HomeDir> module.
-
-=head1 AUTHORS
-
-Adam Kennedy E<lt>adamk@cpan.orgE<gt>
-
-Sean M. Burke E<lt>sburke@cpan.orgE<gt>
-
-=head1 SEE ALSO
-
-L<File::HomeDir>
-
-=head1 COPYRIGHT
-
-Copyright 2005 - 2011 Adam Kennedy.
-
-Some parts copyright 2000 Sean M. Burke.
-
-This program is free software; you can redistribute
-it and/or modify it under the same terms as Perl itself.
-
-The full text of the license can be found in the
-LICENSE file included with this module.
-
-=cut
